# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
from typing import Optional

import pulumi
import pulumi.runtime
from pulumi import Input, ResourceOptions

from ... import tables, version


class ConfigMap(pulumi.CustomResource):
    """
    ConfigMap holds configuration data for pods to consume.
    """

    apiVersion: pulumi.Output[str]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should
    convert recognized schemas to the latest internal value, and may reject unrecognized values.
    More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources
    """

    kind: pulumi.Output[str]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer
    this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More
    info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
    """

    binary_data: pulumi.Output[dict]
    """
    BinaryData contains the binary data. Each key must consist of alphanumeric characters, '-', '_'
    or '.'. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored
    in BinaryData must not overlap with the ones in the Data field, this is enforced during
    validation process. Using this field will require 1.10+ apiserver and kubelet.
    """

    data: pulumi.Output[dict]
    """
    Data contains the configuration data. Each key must consist of alphanumeric characters, '-', '_'
    or '.'. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in
    Data must not overlap with the keys in the BinaryData field, this is enforced during validation
    process.
    """

    immutable: pulumi.Output[bool]
    """
    Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only
    object metadata can be modified). If not set to true, the field can be modified at any time.
    Defaulted to nil. This is an alpha field enabled by ImmutableEphemeralVolumes feature gate.
    """

    metadata: pulumi.Output[dict]
    """
    Standard object's metadata. More info:
    https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """

    def __init__(self, resource_name, opts=None, binary_data=None, data=None, immutable=None, metadata=None, __name__=None, __opts__=None):
        """
        Create a ConfigMap resource with the given unique name, arguments, and options.

        :param str resource_name: The _unique_ name of the resource.
        :param pulumi.ResourceOptions opts: A bag of options that control this resource's behavior.
        :param pulumi.Input[dict] binary_data: BinaryData contains the binary data. Each key must consist of alphanumeric
               characters, '-', '_' or '.'. BinaryData can contain byte sequences that are not in
               the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the
               Data field, this is enforced during validation process. Using this field will require
               1.10+ apiserver and kubelet.
        :param pulumi.Input[dict] data: Data contains the configuration data. Each key must consist of alphanumeric
               characters, '-', '_' or '.'. Values with non-UTF-8 byte sequences must use the
               BinaryData field. The keys stored in Data must not overlap with the keys in the
               BinaryData field, this is enforced during validation process.
        :param pulumi.Input[bool] immutable: Immutable, if set to true, ensures that data stored in the ConfigMap cannot be
               updated (only object metadata can be modified). If not set to true, the field can be
               modified at any time. Defaulted to nil. This is an alpha field enabled by
               ImmutableEphemeralVolumes feature gate.
        :param pulumi.Input[dict] metadata: Standard object's metadata. More info:
               https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'v1'
        __props__['kind'] = 'ConfigMap'
        __props__['binaryData'] = binary_data
        __props__['data'] = data
        __props__['immutable'] = immutable
        __props__['metadata'] = metadata

        __props__['status'] = None

        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(
            version=version.get_version(),
        ))

        super(ConfigMap, self).__init__(
            "kubernetes:core/v1:ConfigMap",
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None):
        """
        Get the state of an existing `ConfigMap` resource, as identified by `id`.
        The ID is of the form `[namespace]/[name]`; if `[namespace]` is omitted,
        then (per Kubernetes convention) the ID becomes `default/[name]`.

        Pulumi will keep track of this resource using `resource_name` as the Pulumi ID.

        :param str resource_name: _Unique_ name used to register this resource with Pulumi.
        :param pulumi.Input[str] id: An ID for the Kubernetes resource to retrieve.
               Takes the form `[namespace]/[name]` or `[name]`.
        :param Optional[pulumi.ResourceOptions] opts: A bag of options that control this
               resource's behavior.
        """
        opts = ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))
        return ConfigMap(resource_name, opts)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop
